summaryrefslogtreecommitdiff
path: root/ucbhelper
diff options
context:
space:
mode:
Diffstat (limited to 'ucbhelper')
-rw-r--r--ucbhelper/source/provider/contenthelper.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/ucbhelper/source/provider/contenthelper.cxx b/ucbhelper/source/provider/contenthelper.cxx
index d29221886bda..c9ce548af225 100644
--- a/ucbhelper/source/provider/contenthelper.cxx
+++ b/ucbhelper/source/provider/contenthelper.cxx
@@ -577,8 +577,8 @@ void SAL_CALL ContentImplHelper::addProperty(
if ( xContainer.is() )
{
- // Property is always removeable.
- Attributes |= beans::PropertyAttribute::REMOVEABLE;
+ // Property is always removable.
+ Attributes |= beans::PropertyAttribute::REMOVABLE;
try
{
@@ -642,9 +642,9 @@ void SAL_CALL ContentImplHelper::removeProperty( const rtl::OUString& Name )
beans::Property aProp
= getPropertySetInfo( xEnv )->getPropertyByName( Name );
- if ( !( aProp.Attributes & beans::PropertyAttribute::REMOVEABLE ) )
+ if ( !( aProp.Attributes & beans::PropertyAttribute::REMOVABLE ) )
{
- // Not removeable!
+ // Not removable!
throw beans::NotRemoveableException();
}
}
@@ -684,7 +684,7 @@ void SAL_CALL ContentImplHelper::removeProperty( const rtl::OUString& Name )
catch ( beans::NotRemoveableException const & )
{
OSL_FAIL(
- "ContentImplHelper::removeProperty - Unremoveable!" );
+ "ContentImplHelper::removeProperty - Unremovable!" );
throw;
}